@@ -1,4 +1,5 @@
 // BaseDisplay.cc for Blackbox - an X11 Window manager
+// Copyright (c) 2001 Sean 'Shaleh' Perry <shaleh@debian.org>
 // Copyright (c) 1997 - 2000 Brad Hughes (bhughes@tcac.net)
 //
 // Permission is hereby granted, free of charge, to any person obtaining a
@@ -33,16 +34,12 @@
 #include <X11/Xatom.h>
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
+#include <X11/keysym.h>
 
 #ifdef    SHAPE
 #  include <X11/extensions/shape.h>
 #endif // SHAPE
 
-#include "i18n.hh"
-#include "BaseDisplay.hh"
-#include "LinkedList.hh"
-#include "Timer.hh"
-
 #ifdef    HAVE_FCNTL_H
 #  include <fcntl.h>
 #endif // HAVE_FCNTL_H
@@ -86,6 +83,10 @@
 #  include <process.h>
 #endif //   HAVE_PROCESS_H             __EMX__
 
+#include "i18n.hh"
+#include "BaseDisplay.hh"
+#include "LinkedList.hh"
+#include "Timer.hh"
 
 // X error handler to handle any and all X errors while the application is
 // running
@@ -94,24 +95,15 @@ static Window last_bad_window = None;
 
 BaseDisplay *base_display;
 
-#ifdef    DEBUG
 static int handleXErrors(Display *d, XErrorEvent *e) {
+#ifdef    DEBUG
   char errtxt[128];
 
   XGetErrorText(d, e->error_code, errtxt, 128);
-  fprintf(stderr,
-	  i18n->
-	  getMessage(
-#ifdef    NLS
-		     BaseDisplaySet, BaseDisplayXError,
-#else // !NLS
-		     0, 0,
-#endif // NLS
+  fprintf(stderr, i18n->getMessage(BaseDisplaySet, BaseDisplayXError,
 		     "%s:  X error: %s(%d) opcodes %d/%d\n  resource 0x%lx\n"),
           base_display->getApplicationName(), errtxt, e->error_code,
           e->request_code, e->minor_code, e->resourceid);
-#else // !DEBUG
-static int handleXErrors(Display *, XErrorEvent *e) {
 #endif // DEBUG
 
   if (e->error_code == BadWindow) last_bad_window = e->resourceid;
@@ -154,40 +146,22 @@ static void signalhandler(int sig) {
       return;
     }
 
-    fprintf(stderr,
-	    i18n->getMessage(
-#ifdef    NLS
-			     BaseDisplaySet, BaseDisplaySignalCaught,
-#else // !NLS
-			     0, 0,
-#endif // NLS
-			     "%s:  signal %d caught\n"),
+    fprintf(stderr, i18n->getMessage(BaseDisplaySet, BaseDisplaySignalCaught,
+				     "%s:  signal %d caught\n"),
 	    base_display->getApplicationName(), sig);
 
     if (! base_display->isStartup() && ! re_enter) {
       internal_error = True;
 
       re_enter = 1;
-      fprintf(stderr,
-	      i18n->getMessage(
-#ifdef    NLS
-			       BaseDisplaySet, BaseDisplayShuttingDown,
-#else // !NLS
-			       0, 0,
-#endif // NLS
-			       "shutting down\n"));
+      fprintf(stderr, i18n->getMessage(BaseDisplaySet, BaseDisplayShuttingDown,
+				       "shutting down\n"));
       base_display->shutdown();
     }
 
     if (sig != SIGTERM && sig != SIGINT) {
-      fprintf(stderr,
-	      i18n->getMessage(
-#ifdef    NLS
-			       BaseDisplaySet, BaseDisplayAborting,
-#else // !NLS
-			       0, 0,
-#endif // NLS
-			       "aborting... dumping core\n"));
+      fprintf(stderr, i18n->getMessage(BaseDisplaySet, BaseDisplayAborting,
+				       "aborting... dumping core\n"));
       abort();
     }
 
@@ -210,15 +184,13 @@ void bexec(const char *command, char* displaystring) {
 }
 #endif // !__EMX__
 
-
 char *bstrdup(const char *s) {
-  int l = strlen(s) + 1;
+  const int l = strlen(s) + 1;
   char *n = new char[l];
   strncpy(n, s, l);
   return n;
 }
 
-
 BaseDisplay::BaseDisplay(char *app_name, char *dpy_name) {
   application_name = app_name;
 
@@ -236,6 +208,7 @@ BaseDisplay::BaseDisplay(char *app_name, char *dpy_name) {
   action.sa_mask = sigset_t();
   action.sa_flags = SA_NOCLDSTOP | SA_NODEFER;
 
+  sigaction(SIGPIPE, &action, NULL);
   sigaction(SIGSEGV, &action, NULL);
   sigaction(SIGFPE, &action, NULL);
   sigaction(SIGTERM, &action, NULL);
@@ -245,6 +218,7 @@ BaseDisplay::BaseDisplay(char *app_name, char *dpy_name) {
   sigaction(SIGUSR1, &action, NULL);
   sigaction(SIGUSR2, &action, NULL);
 #else // !HAVE_SIGACTION
+  signal(SIGPIPE, (RETSIGTYPE (*)(int)) signalhandler);
   signal(SIGSEGV, (RETSIGTYPE (*)(int)) signalhandler);
   signal(SIGFPE, (RETSIGTYPE (*)(int)) signalhandler);
   signal(SIGTERM, (RETSIGTYPE (*)(int)) signalhandler);
@@ -256,27 +230,14 @@ BaseDisplay::BaseDisplay(char *app_name, char *dpy_name) {
 #endif // HAVE_SIGACTION
 
   if (! (display = XOpenDisplay(dpy_name))) {
-    fprintf(stderr,
-            i18n->
-	    getMessage(
-#ifdef    NLS
-		       BaseDisplaySet, BaseDisplayXConnectFail,
-#else // !NLS
-		       0, 0,
-#endif // NLS
-		       "BaseDisplay::BaseDisplay: connection to X server failed.\n"));
+    fprintf(stderr, i18n->getMessage(BaseDisplaySet, BaseDisplayXConnectFail,
+	       "BaseDisplay::BaseDisplay: connection to X server failed.\n"));
     ::exit(2);
   } else if (fcntl(ConnectionNumber(display), F_SETFD, 1) == -1) {
     fprintf(stderr,
-            i18n->
-	    getMessage(
-#ifdef    NLS
-		       BaseDisplaySet, BaseDisplayCloseOnExecFail,
-#else // !NLS
-		       0, 0,
-#endif // NLS
-		       "BaseDisplay::BaseDisplay: couldn't mark display connection "
-		       "as close-on-exec\n"));
+	    i18n->getMessage(BaseDisplaySet, BaseDisplayCloseOnExecFail,
+	       "BaseDisplay::BaseDisplay: couldn't mark display connection "
+	       "as close-on-exec\n"));
     ::exit(2);
   }
 
@@ -373,11 +334,48 @@ BaseDisplay::BaseDisplay(char *app_name, char *dpy_name) {
   timerList = new LinkedList<BTimer>;
 
   screenInfoList = new LinkedList<ScreenInfo>;
-  int i;
-  for (i = 0; i < number_of_screens; i++) {
+  for (int i = 0; i < number_of_screens; i++) {
     ScreenInfo *screeninfo = new ScreenInfo(this, i);
     screenInfoList->insert(screeninfo);
   }
+
+  NumLockMask = ScrollLockMask = 0;
+
+  const XModifierKeymap* const modmap = XGetModifierMapping(display);
+  if (modmap && modmap->max_keypermod > 0) {
+    const int mask_table[] = {
+      ShiftMask, LockMask, ControlMask, Mod1Mask,
+      Mod2Mask, Mod3Mask, Mod4Mask, Mod5Mask
+    };
+    const size_t size = (sizeof(mask_table) / sizeof(mask_table[0])) *
+      modmap->max_keypermod;
+    // get the values of the keyboard lock modifiers
+    // Note: Caps lock is not retrieved the same way as Scroll and Num lock
+    // since it doesn't need to be.
+    const KeyCode num_lock_code = XKeysymToKeycode(display, XK_Num_Lock);
+    const KeyCode scroll_lock_code = XKeysymToKeycode(display, XK_Scroll_Lock);
+    
+    for (size_t cnt = 0; cnt < size; ++cnt) {
+      if (! modmap->modifiermap[cnt]) continue;
+
+      if (num_lock_code == modmap->modifiermap[cnt])
+	NumLockMask = mask_table[cnt / modmap->max_keypermod];
+      if (scroll_lock_code == modmap->modifiermap[cnt])
+	ScrollLockMask = mask_table[cnt / modmap->max_keypermod];
+    }
+  }
+
+  MaskList[0] = 0;
+  MaskList[1] = LockMask;
+  MaskList[2] = NumLockMask;
+  MaskList[3] = ScrollLockMask;
+  MaskList[4] = LockMask | NumLockMask;
+  MaskList[5] = NumLockMask  | ScrollLockMask;
+  MaskList[6] = LockMask | ScrollLockMask;
+  MaskList[7] = LockMask | NumLockMask | ScrollLockMask;
+  MaskListLength = sizeof(MaskList) / sizeof(MaskList[0]);
+  
+  if (modmap) XFreeModifiermap(const_cast<XModifierKeymap*>(modmap));
 }
 
 
@@ -413,14 +411,8 @@ void BaseDisplay::eventLoop(void) {
 
       if (last_bad_window != None && e.xany.window == last_bad_window) {
 #ifdef    DEBUG
-      fprintf(stderr,
-	      i18n->
-	      getMessage(
-#ifdef    NLS
-			 BaseDisplaySet, BaseDisplayBadWindowRemove,
-#else // !NLS
-			 0, 0,
-#endif // NLS
+      fprintf(stderr, i18n->getMessage(BaseDisplaySet,
+				       BaseDisplayBadWindowRemove,
 			 "BaseDisplay::eventLoop(): removing bad window "
 			 "from event queue\n"));
 #endif // DEBUG
@@ -471,21 +463,21 @@ void BaseDisplay::eventLoop(void) {
       gettimeofday(&now, 0);
 
       LinkedListIterator<BTimer> it(timerList);
-      for(; it.current(); it++) {
-        tm.tv_sec = it.current()->getStartTime().tv_sec +
-          it.current()->getTimeout().tv_sec;
-        tm.tv_usec = it.current()->getStartTime().tv_usec +
-          it.current()->getTimeout().tv_usec;
+      for(BTimer *timer = it.current(); timer; it++, timer = it.current()) {
+        tm.tv_sec = timer->getStartTime().tv_sec +
+          timer->getTimeout().tv_sec;
+        tm.tv_usec = timer->getStartTime().tv_usec +
+          timer->getTimeout().tv_usec;
 
         if ((now.tv_sec < tm.tv_sec) ||
             (now.tv_sec == tm.tv_sec && now.tv_usec < tm.tv_usec))
           break;
 
-        it.current()->fireTimeout();
+        timer->fireTimeout();
 
         // restart the current timer so that the start time is updated
-        if (! it.current()->doOnce()) it.current()->start();
-        else it.current()->stop();
+        if (! timer->doOnce()) timer->start();
+        else timer->stop();
       }
     }
   }
@@ -523,10 +515,10 @@ void BaseDisplay::addTimer(BTimer *timer) {
 
   LinkedListIterator<BTimer> it(timerList);
   int index = 0;
-  for (; it.current(); it++, index++)
-    if ((it.current()->getTimeout().tv_sec > timer->getTimeout().tv_sec) ||
-        ((it.current()->getTimeout().tv_sec == timer->getTimeout().tv_sec) &&
-         (it.current()->getTimeout().tv_usec >= timer->getTimeout().tv_usec)))
+  for (BTimer *tmp = it.current(); tmp; it++, index++, tmp = it.current())
+    if ((tmp->getTimeout().tv_sec > timer->getTimeout().tv_sec) ||
+        ((tmp->getTimeout().tv_sec == timer->getTimeout().tv_sec) &&
+         (tmp->getTimeout().tv_usec >= timer->getTimeout().tv_usec)))
       break;
 
   timerList->insert(timer, index);
@@ -538,6 +530,35 @@ void BaseDisplay::removeTimer(BTimer *timer) {
 }
 
 
+/*
+ * Grabs a button, but also grabs the button in every possible combination with
+ * the keyboard lock keys, so that they do not cancel out the event.
+ */
+void BaseDisplay::grabButton(unsigned int button, unsigned int modifiers,
+			     Window grab_window, Bool owner_events,
+			     unsigned int event_mask, int pointer_mode,
+			     int keybaord_mode, Window confine_to,
+			     Cursor cursor) const
+{
+  for (size_t cnt = 0; cnt < MaskListLength; ++cnt) {
+    XGrabButton(display, button, modifiers | MaskList[cnt], grab_window,
+        owner_events, event_mask, pointer_mode, keybaord_mode, confine_to,
+        cursor);
+  }
+}
+
+/*
+ * Releases the grab on a button, and ungrabs all possible combinations of the
+ * keyboard lock keys.
+ */
+void BaseDisplay::ungrabButton(unsigned int button, unsigned int modifiers,
+			       Window grab_window) const {
+  for (size_t cnt = 0; cnt < MaskListLength; ++cnt) {
+    XUngrabButton(display, button, modifiers | MaskList[cnt], grab_window);
+  }
+}
+
+
 ScreenInfo::ScreenInfo(BaseDisplay *d, int num) {
   basedisplay = d;
   screen_number = num;
@@ -574,10 +595,10 @@ ScreenInfo::ScreenInfo(BaseDisplay *d, int num) {
     XFree(vinfo_return);
   }
 
-  if (visual)
+  if (visual) {
     colormap = XCreateColormap(basedisplay->getXDisplay(), root_window,
 			       visual, AllocNone);
-  else {
+  } else {
     visual = DefaultVisual(basedisplay->getXDisplay(), screen_number);
     colormap = DefaultColormap(basedisplay->getXDisplay(), screen_number);
   }
